#
# spec file for package queue
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           queue
Version:        1.3.0
Release:        1.1
Summary:        Tool for queuing shell commands
License:        GPL-3.0-or-later
URL:            https://codeberg.org/asdil12/%{name}
Source0:        https://codeberg.org/asdil12/queue/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-base >= 3.6
BuildRequires:  python3-pip
BuildRequires:  python3-psutil
BuildRequires:  python3-setuptools
BuildRequires:  python3-termcolor
BuildRequires:  python3-tomlkit
BuildRequires:  python3-wheel
Requires:       python3-psutil
Requires:       python3-termcolor
Requires:       python3-tomlkit
BuildArch:      noarch

%description
This tool allows to queue shell commands.
It supports multiple queues as well as multiple queue workers.

%prep
%setup -q -n queue

%build
./bin/queue
help2man -s8 -N ./bin/queue -n "Queue shell commands" > queue.8
%python3_pyproject_wheel

%install
%python3_pyproject_install
install -m 644 -D -v queue.8 %{buildroot}%{_mandir}/man8/queue.8
%{python3_fix_shebang}
%fdupes %{buildroot}%{python3_sitelib}

%check
python3 setup.py --version | grep %{version}

%files
%license LICENSE
%doc README.md
%{_bindir}/queue
%{_mandir}/man8/queue.8%{?ext_man}
%{python3_sitelib}/cmdqueue
%{python3_sitelib}/cmdqueue-%{version}*-info

%changelog
* Sat Jun 21 2025 Dominik Heidler <dheidler@suse.de>
- Version 1.2.0
- Ignore broken pipe error (e.g. when piping to head)
* Sat Dec 28 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.2.0
- Only use dark_grey if available
- Do osc sr in release.sh
* Sat Dec 28 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.1.0
- Color scheduled and running entries differently
- Enable multi column limiting
- Add hint about config location
* Mon Dec 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%python3_pyproject_wheel instead of all-python-flavors
  %%pyproject_wheel and do not redefine pythons. It's just more in
  line of what the package is actually about.
* Mon Dec 16 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.0.0
- Add config option to use pager
- Print info when starting runner
- Fix issues with timestamps on the exact second (with ms=0)
* Tue Dec 10 2024 Dominik Heidler <dheidler@suse.de>
- Initial checkin.
